colour.models.dataset.adobe_wide_gamut_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.adobe_wide_gamut_rgb Module

## Adobe Wide Gamut RGB Colourspace

Defines the Adobe Wide Gamut RGB colourspace:

- `ADOBE_WIDE_GAMUT_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://en.wikipedia.org/wiki/Wide-gamut_RGB_color_space (Last accessed 13 April 2014)

`colour.models.dataset.adobe_wide_gamut_rgb.` `ADOBE_WIDE_GAMUT_RGB_PRIMARIES` = array([[ 0.7347, 0.2653], [ 0.1152, 0.8264], [ 0.1566, 0.0177]])

  Adobe Wide Gamut RGB colourspace primaries.

  ADOBE_WIDE_GAMUT_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.adobe_wide_gamut_rgb.` `ADOBE_WIDE_GAMUT_RGB_WHITEPOINT` = (0.34567, 0.3585)

  Adobe Wide Gamut RGB colourspace whitepoint.

  ADOBE_WIDE_GAMUT_RGB_WHITEPOINT : tuple

`colour.models.dataset.adobe_wide_gamut_rgb.` `ADOBE_WIDE_GAMUT_RGB_TO_XYZ_MATRIX` = array([[ 0.71639665, 0.10102557, 0.14678978], [ 0.25869066, 0.72471815, 0.01659118], [ 0. , 0.05121435, 0.77397393]])

  Adobe Wide Gamut RGB colourspace to CIE XYZ colourspace matrix.

  ADOBE_WIDE_GAMUT_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.adobe_wide_gamut_rgb.` `XYZ_TO_ADOBE_WIDE_GAMUT_RGB_MATRIX` = array([[ 1.46251661, -0.18455245, -0.27342076], [-0.52284242, 1.4479168 , 0.0681228 ], [ 0.03459682, -0.09580958, 1.28752545]])

  CIE XYZ colourspace to Adobe Wide Gamut RGB colourspace matrix.

  XYZ_TO_ADOBE_WIDE_GAMUT_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.adobe_wide_gamut_rgb.` `ADOBE_WIDE_GAMUT_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Adobe Wide Gamut RGB colourspace.

  ADOBE_WIDE_GAMUT_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.adobe_wide_gamut_rgb.` `ADOBE_WIDE_GAMUT_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Adobe Wide Gamut RGB colourspace to linear.

  ADOBE_WIDE_GAMUT_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.adobe_wide_gamut_rgb.` `ADOBE_WIDE_GAMUT_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12810>

  Adobe Wide Gamut RGB colourspace.

  ADOBE_WIDE_GAMUT_RGB_COLOURSPACE : RGB_Colourspace